import {
  select,
  csv,
  scaleLinear,
  max,
  scaleBand,
  axisLeft,
  axisBottom
} from 'd3';

const svg = select('svg');

const height = +svg.attr('height');
const width = +svg.attr('width');

const render = data => {
  const getXValue = d => d.population;
  const getYValue = d => d.country;
  const margin = {
    top: 20,
    right: 40,
    bottom: 20,
    left: 100
  };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleLinear()
  	.domain([0, max(data, getXValue)])
  	.range([0, innerWidth]);

  const yScale = scaleBand()
  	.domain(data.map(getYValue))
  	.range([0, innerHeight])
  	.padding(0.1);
  
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left}, ${margin.top})`)
  
	g.append('g').call(axisLeft(yScale));
  g.append('g').call(axisBottom(xScale))
  	.attr('transform', `translate(0, ${innerHeight})`)
  
	g.selectAll('rect').data(data)
  	.enter().append('rect')
  	.attr('y', d => yScale(getYValue(d)))
  	.attr('width', d => xScale(getXValue(d)))
    .attr('height', yScale.bandwidth())
}

const formatData = data => {
	return { ...data, population: +data.population * 1000 };
}

csv('data.csv').then(data => {
	const transData = data.map(formatData);
  render(transData);
});

